@@ -1,9 +1,9 @@
 my $tot = "@ARGV";
 if( $tot =~ m/\.cc$/ ) {
-  $cmd = "g++ $tot >& res";
+  $cmd = "g++ $tot > res";
 }
 if( $tot =~ m/\.c$/ ) {
-  $cmd = "gcc $tot >& res";
+  $cmd = "gcc $tot > res";
 }
 print $cmd."\n";
 $res = system( $cmd );
